==> freeipmi-1.1.4.tar.gz: freeipmi-1.1.4/ipmipower/ipmipower_prompt.h <==
/*****************************************************************************\
 *  $Id: ipmipower_prompt.h,v 1.14 2010-02-08 22:02:31 chu11 Exp $
 *****************************************************************************
 *  Copyright (C) 2007-2012 Lawrence Livermore National Security, LLC.
 *  Copyright (C) 2003-2007 The Regents of the University of California.
 *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
 *  Written by Albert Chu <chu11@llnl.gov>
 *  UCRL-CODE-155698
 *
 *  This file is part of Ipmipower, a remote power control utility.
 *  For details, see http://www.llnl.gov/linux/.
 *
 *  Ipmipower is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; either version 3 of the License, or (at your
 *  option) any later version.
 *
 *  Ipmipower is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 *  for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with Ipmipower.  If not, see <http://www.gnu.org/licenses/>.
\*****************************************************************************/

#ifndef _IPMIPOWER_PROMPT_H
#define _IPMIPOWER_PROMPT_H

#include "ipmipower.h"

/* ipmipower_prompt_process_cmdline
 * - Process a single line
 * - Do nothing if power commands still pending and processing
 * Returns 1 if we should continue, 0 if we should quit
 */
int ipmipower_prompt_process_cmdline (void);

#endif /* _IPMIPOWER_PROMPT_H */

==> freeipmi-1.2.2.tar.gz: freeipmi-1.2.2/ipmipower/ipmipower_prompt.h <==
/*****************************************************************************\
 *  $Id: ipmipower_prompt.h,v 1.14 2010-02-08 22:02:31 chu11 Exp $
 *****************************************************************************
 *  Copyright (C) 2007-2012 Lawrence Livermore National Security, LLC.
 *  Copyright (C) 2003-2007 The Regents of the University of California.
 *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
 *  Written by Albert Chu <chu11@llnl.gov>
 *  UCRL-CODE-155698
 *
 *  This file is part of Ipmipower, a remote power control utility.
 *  For details, see http://www.llnl.gov/linux/.
 *
 *  Ipmipower is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; either version 3 of the License, or (at your
 *  option) any later version.
 *
 *  Ipmipower is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 *  for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with Ipmipower.  If not, see <http://www.gnu.org/licenses/>.
\*****************************************************************************/

#ifndef IPMIPOWER_PROMPT_H
#define IPMIPOWER_PROMPT_H

#include "ipmipower.h"

/* ipmipower_prompt_process_cmdline
 * - Process a single line
 * - Do nothing if power commands still pending and processing
 * Returns 1 if we should continue, 0 if we should quit
 */
int ipmipower_prompt_process_cmdline (void);

#endif /* IPMIPOWER_PROMPT_H */
